@@ -1,7 +1,7 @@
 ## Graph.pm is a graphing package that supports on-the-fly graphing 
 ## from the gnuplot, XRT, and Xmgrace graphing packages.
 ##
-## $Id: Graph.pm,v 1.48 2006/06/07 21:09:32 emile Exp $ $Name:  $
+## $Id: Graph.pm,v 1.51 2013/02/25 06:28:53 rkoga Exp $ $Name:  $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -39,15 +39,15 @@
 package Chart::Graph;
 use Exporter();
 
-$VERSION = '3.2';
+$VERSION = '3.3';
 @ISA = qw(Exporter);
 @EXPORT = qw();
 @EXPORT_OK = qw(&gnuplot &xrt3d &xrt2d &xmgrace);
 
-$cvs_Id = '$Id: Graph.pm,v 1.48 2006/06/07 21:09:32 emile Exp $';
-$cvs_Author = '$Author: emile $';
+$cvs_Id = '$Id: Graph.pm,v 1.51 2013/02/25 06:28:53 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
 $cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.48 $';
+$cvs_Revision = '$Revision: 1.51 $';
 
 use Chart::Graph::Utils qw(:USER);
 use Chart::Graph::Gnuplot qw(&gnuplot);
@@ -234,7 +234,7 @@ files for Graph.pm are located in the F<doc> directory.
 
 For more information on gnuplot, please see the gnuplot web page:
 
- http://www.gnuplot.org/
+ http://www.gnuplot.info/
 
 For more information on Xmgrace, please see the Xmgrace web page:
 
@@ -246,8 +246,8 @@ For more information on XRT, please contact Sitraka (now Quest):
 
 =head1 CONTACT
 
-Send email to graph-dev@caida.org is you have problems, questions,
-or comments. To subscribe to the mailing list send mail to
+Send email to the graph-dev@caida.org mailing list if you have problems,
+questions, or comments. To subscribe to this mailing list send mail to
 graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
 =head1 AUTHOR
@@ -258,6 +258,5 @@ graph-dev-request@caida.org with a body of "subscribe your@email.com"
 
  gnuplot(1).
  xmgrace(1).
- 
 
 =cut
