@@ -1,7 +1,7 @@
 ## Gnuplot.pm is a sub-module of Graph.pm. It has all the subroutines 
 ## needed for the gnuplot part of the package.
 ##
-## $Id: Gnuplot.pm,v 1.48 2006/06/07 21:09:33 emile Exp $ $Name:  $
+## $Id: Gnuplot.pm,v 1.54 2013/02/25 06:28:32 rkoga Exp $ $Name:  $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -49,12 +49,12 @@ use Chart::Graph::Utils qw(:UTILS);	# get global subs and variable
 use POSIX 'strftime';
 use FileHandle;
 
-$cvs_Id = '$Id: Gnuplot.pm,v 1.48 2006/06/07 21:09:33 emile Exp $';
-$cvs_Author = '$Author: emile $';
+$cvs_Id = '$Id: Gnuplot.pm,v 1.54 2013/02/25 06:28:32 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
 $cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.48 $';
+$cvs_Revision = '$Revision: 1.54 $';
 
-$VERSION = 3.2;
+$VERSION = 3.3;
 
 use strict;
 
@@ -130,7 +130,7 @@ sub gnuplot {
     
     # check first arg for hash
     if (ref($user_global_opts_ref) ne "HASH") {
-	carp "Global options must be a hash";
+	carp "Global options must be a hash ref";
 	_cleanup_tmpdir();
 	return 0;
     }
@@ -301,23 +301,29 @@ sub gnuplot {
 	    if (defined($value)) { 
 		if (ref($value) eq 'ARRAY') {
 		    # arrayref
-		    print $handle "set $key [$value->[0] : $value->[1]]\n";
+		    print $handle "set $key [$value->[0]:$value->[1]]\n";
 		} else {
 		    # assume string
 		    print $handle "set $key $value\n";
 		}
-	    }
+	    } 
 	}
 	# The only time related Gnuplot code that doesn't need to be
 	# output first.
 	if ($key eq "format") {
 	    if (defined($value)) {
 		if(ref($value) eq "ARRAY") {
+                    my %format_opts = @$value;
+                    foreach my $axis (keys %format_opts) {
 		    # Print value supplying quotes for time format.
-		    print $handle "set $key ", $$value[0]," \"",
-			$$value[1], "\" \n";
+                        if ($axis !~ /^(x|y|x2|y2)$/ ) {
+                            carp "Invalid axis '$axis' for format option, ignoring";
+                            next;
+                        }
+                        print $handle "set format $axis \"$format_opts{$axis}\"\n";
+                    }
 		} else {
-		    carp "Invalid setting for format option";
+		    carp "Invalid setting for format option, please use an array_ref, example: ['x','%.0f']";
 		}
 	    }
 	}
@@ -358,7 +364,7 @@ sub gnuplot {
 	}
 	
 	if ($key eq "output type") {
-	    if (!($value =~ /^(pbm|gif|tgif|png|svg|eps(:? .*)?)$/)) {
+	    if (!($value =~ /^(pbm|gif|tgif|svg|png|eps)( .*)?$/)) {
 		carp "invalid output type: $value";
 		$handle->close();
 		_cleanup_tmpdir();
@@ -368,44 +374,22 @@ sub gnuplot {
 	}
     }
 
-    # create the data file
-    if ($output_type =~ /^eps( .*)?$/) {
-	my $options = $1 || "";
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "eps");
+    my %default_type_options = (
+        'pbm' => 'small color',
+        'png' => 'small',
+    );
+    if ($output_type =~ /^(pbm|gif|tgif|svg|png|eps)( .*)?$/ ) {
+        my $type = $1;
+        $type = 'postscript eps' if ($type eq 'eps');
+        my $options = $2 || $default_type_options{$type} || "";
+        if (defined $output_file) {
+            $plot_file = _make_tmpfile("plot",$type);
 	    print $handle "set output \"$plot_file\"\n";
-	}
-	#print $handle "set terminal postscript eps color \"Arial\" 18\n";
-	print $handle "set terminal postscript eps $options\n";
-    } elsif ($output_type eq "pbm" ) {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "pbm");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal pbm small color\n";
-    } elsif ($output_type eq "gif") {
-	# always needs the tempfile because of conversion later on
-	$plot_file = _make_tmpfile("plot", "pbm");
-	print $handle "set output \"$plot_file\"\n";
-	print $handle "set terminal pbm small color\n";
-    } elsif ($output_type eq "png") {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "png");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal png small\n";
-    } elsif ($output_type eq "tgif") {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "obj");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal tgif\n";
-    } elsif ($output_type eq 'svg') {
-	if (defined $output_file) {
-	    $plot_file = _make_tmpfile("plot", "svg");
-	    print $handle "set output \"$plot_file\"\n";
-	}
-	print $handle "set terminal svg\n";
+        }
+	print $handle "set terminal $type $options\n";
+    } else {
+        # DIE DIE DIE
+        croak "can't happen, output types already checked\n";
     }
 
     # process data sets
@@ -434,19 +418,15 @@ sub gnuplot {
     }	
     
     $handle->close();
-	
-    # gnuplot and convert pbm file to gif
+
+    # gnuplot
     if (not _exec_gnuplot($command_file)) {
 	_cleanup_tmpdir();
 	return 0;
     }
-    
-    if ($output_type eq "gif") {
-	if(not _exec_pbmtogif($plot_file, $output_file)) {
-	    _cleanup_tmpdir();
-	    return 0;
-	}
-    } elsif (defined $output_file && $output_type =~ /^(pbm|eps(?: .*)?|png|tgif)$/) {
+   
+    # removed pbm to gif conversion code here
+    if (defined $output_file && $output_type =~ /^(pbm|eps|svg|png|tgif|gif)/) {
 	#try to get rid of the ugly warnings when moving a file on freebsd
 	if ($^O eq 'freebsd') {
 	    eval { #this is opportunistic, if it fails it doesn't really matter
@@ -571,12 +551,7 @@ sub _set_gnupaths {
 	    return 0;
 	}
     }
-   
-    if (not defined($ppmtogif)) {
-	if (not $ppmtogif = _get_path("ppmtogif")) {
-	    return 0;
-	}
-    }
+    # removed ppmtogif dependency here
     return 1;
 }
 
@@ -761,6 +736,13 @@ sub _file_to_file {
 
 sub _exec_gnuplot {
     my ($command_file) = @_;
+	 ## newer gnuplot will assume you have an X display
+	 ## avaiable if TERM=xterm , make sure this doesn't happen
+	 ### still won't work if DISPLAY is set to something gnuplot
+	 ### can't connect to
+	 if (defined $ENV{'TERM'} && $ENV{'TERM'} =~ /^xterm/ ) { 
+	 	$ENV{'TERM'} = '';
+	 };
     my $status = system("$gnuplot", "$command_file");
     
     if (not _chk_status($status)) {
@@ -770,6 +752,7 @@ sub _exec_gnuplot {
     return 1;
 }	
 
+=cut
 #
 # Subroutine: exec_pbmtogif()
 # 
@@ -794,6 +777,7 @@ sub _exec_pbmtogif {
     
     return 1;
 }
+=cut
 
 #
 # Subroutine: gnuplot_date_utc()
@@ -1039,7 +1023,9 @@ application.
  +----------------+-----------------------------+-----------------------------+
  |'title'         |  set your own title         |     'untitled'              |
  |'output type'   |  'pbm','gif','tgif','png',  |     'png'                   |
- |                |   'svg' or "eps $epsoptions"|                             |
+ |                |   'svg' or 'eps'            |                             |
+ |                |  you can add terminal opts  |                             |
+ |                |  like 'png size 600,1200'   |                             |
  |'output file'   |  set your own output file,  |     'untitled-gnuplot.png'  |
  |                |   undef to output to STDOUT |                             |
  |'x-axis label'  |  set your own label         |     'x-axis'                |
@@ -1078,10 +1064,11 @@ application.
  |                |  y2-axis is date/time data  |                             |
  | 'timefmt'      | "Input date/time string"    |     none                    |
  |                |  see Gnuplot manual for info|                             |
- | 'format'       | array ref: First element is |                             |
- |                |  axis: 'x', 'y', 'x2', 'y2'.|                             |
- |                |  Second element is          |                             |
- |                |  'output date/time string"  |                             |
+ | 'format'       | array ref: pairs of axis    |                             |
+ |                |  and 'output format string' |                             |
+ |                |  axis is in (x|y|x2|y2)     |                             |
+ |                |  see examples for use on    |                             |
+ |                |  multiple axes              |                             |
  |                |  see Gnuplot manual for info|                             |
  | 'extra_opts'   | set your own Gnuplot        |     none                    |
  |                |  options, either an arrayref|                             |
@@ -1584,6 +1571,7 @@ be mixed with other data-types:
 <p><center><img src="http://www.caida.org/tools/utilities/graphing/gnuplot5.png"></center></p>
 <p><center><em>gnuplot5.png</em></center></p>
 
+#TODO example of format on multiple axis
 
 =head1 MORE INFO
 
@@ -1593,7 +1581,7 @@ on older versions of gnuplot.
 
 For more information on gnuplot, please see the gnuplot web page:
 
- http://www.gnuplot.org/
+ http://www.gnuplot.info/
 
 =head1 CONTACT
 
