@@ -1,7 +1,7 @@
 ## Graph.pm is a graphing package that supports on-the-fly graphing 
 ## from the gnuplot, xrt, and xmgrace  graphing packages.
 ##
-## $Id: Utils.pm,v 1.24 2006/06/07 21:09:33 emile Exp $ $Name:  $
+## $Id: Utils.pm,v 1.25 2013/02/25 06:28:53 rkoga Exp $ $Name:  $
 ##
 ## This software product is developed by Michael Young and David Moore,
 ## and copyrighted(C) 1998 by the University of California, San Diego
@@ -61,12 +61,12 @@ Exporter::export_ok_tags('UTILS');
 use Carp;			# for carp() and croak()
 use File::Path;	                # for rmtree()
 
-$cvs_Id = '$Id: Utils.pm,v 1.24 2006/06/07 21:09:33 emile Exp $';
-$cvs_Author = '$Author: emile $';
+$cvs_Id = '$Id: Utils.pm,v 1.25 2013/02/25 06:28:53 rkoga Exp $';
+$cvs_Author = '$Author: rkoga $';
 $cvs_Name = '$Name:  $';
-$cvs_Revision = '$Revision: 1.24 $';
+$cvs_Revision = '$Revision: 1.25 $';
 
-$VERSION = 3.2;
+$VERSION = 3.3;
 
 use strict;
 
