@@ -3,7 +3,7 @@ package t::Config;
 @drivers    = qw(gnuplot xmgrace);
 $xrt3d      = "";
 $xrt2d      = "";
-$xvfb      = "";
+$xvfb      = "/usr/bin/Xvfb";
 
 1;
 
